/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration DSPIC :
    
    MCU             : P33FJ256GP710A
    Dev. Board      : EasyPIC Fusion v7
    SW              : mikroC PRO for dsPIC v7.0.1

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.    
    Board specific: Button press level PA to VCC, and PORTA pull down RA0 and RA4, 
    speed is controlled by pressing RA0 and direction is changed by pressing RA4.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at RC1_bit;
sbit MOTOR_DIR_PIN_Direction at TRISC1_bit;

uint16_t const maxPwmDuty = 5000;
uint16_t currentDuty = 0;
uint8_t oldstate = 0;

void systemInit()
{
    CLKDIVbits.PLLPRE = 0;   // PLLPRE<4:0> = 0  ->  N1 = 2    8MHz / 2 = 4MHz
                             // (must be within 0.8 MHz to 8 MHz range)
    PLLFBD =   38;           // PLLDIV<8:0> = 38 ->  M = 40    4MHz * 40 = 160MHz
                             // (must be within 100 MHz to 200 MHz range)
    CLKDIVbits.PLLPOST = 0;  // PLLPOST<1:0> = 0 ->  N2 = 2    160MHz / 2 = 80MHz
                             // (must be within 12.5 MHz to 80 MHz range)

    AD1PCFGL = 0xFFFE;       // Set All pins as digital
    AD1PCFGH = 0xFFFF;
    currentDuty = PWM_Init(5000, 1, 1, 2);
    PWM_Start(1);
    PWM_Set_Duty(currentDuty, 1);
    MOTOR_DIR_PIN_Direction = 0;
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&PORTA, 0, 1, 1))
    {
        currentDuty++;
        PWM_Set_Duty(currentDuty, 1);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&PORTA, 4, 1, 1)) 
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&PORTA, 4, 1, 0)) 
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0; 
    }                             
}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}